==> haskell-nonce-1.0.7-51-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-nonce.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: nonce
version: 1.0.7
id: nonce-1.0.7-2t7g2ii3h1cAmFQIahBCfM
key: nonce-1.0.7-2t7g2ii3h1cAmFQIahBCfM
license: BSD-3-Clause
copyright: (c) 2014 Prowdsponsor
maintainer: Prowdsponsor <opensource@prowdsponsor.com>
author: Felipe Lessa <felipe.lessa@prowdsponsor.com>
homepage: https://github.com/prowdsponsor/nonce
synopsis: Generate cryptographic nonces.
description:
    According to the Wikipedia, a nonce is an arbitrary number used
    only once in a cryptographic communication.  This package
    contain helper functions for generating nonces.
    .
    There are many kinds of nonces used in different situations.
    It'\''s not guaranteed that by using the nonces from this package
    you won'\''t have any security issues.  Please make sure that the
    nonces generated via this package are usable on your design.
category: Cryptography
abi: 790c332b28ec7aaa11ccf3e60a3ca09a
exposed: True
exposed-modules:
    Crypto.Nonce
import-dirs: /usr/lib/ghc-8.6.5/site-local/nonce-1.0.7
library-dirs: /usr/lib/ghc-8.6.5/site-local/nonce-1.0.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/nonce-1.0.7
hs-libraries: HSnonce-1.0.7-2t7g2ii3h1cAmFQIahBCfM
depends:
    base-4.12.0.0 base64-bytestring-1.0.0.2-9hYbO3I2I9012gU046eVdX
    bytestring-0.10.8.2 entropy-0.4.1.4-23NMAjgKyCo3F1ZCvvDJOh
    text-1.2.3.1 transformers-0.5.6.2
    unliftio-0.2.10-6BpS3bT3tbj8Fq9fxLSEC3
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
haddock-interfaces: /usr/share/doc/haskell-nonce/html/nonce.haddock
haddock-html: /usr/share/doc/haskell-nonce/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-nonce-1.0.7-56-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-nonce.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: nonce
version: 1.0.7
id: nonce-1.0.7-AfBGIvGcu2v3eRB2elWNvo
key: nonce-1.0.7-AfBGIvGcu2v3eRB2elWNvo
license: BSD-3-Clause
copyright: (c) 2014 Prowdsponsor
maintainer: Prowdsponsor <opensource@prowdsponsor.com>
author: Felipe Lessa <felipe.lessa@prowdsponsor.com>
homepage: https://github.com/prowdsponsor/nonce
synopsis: Generate cryptographic nonces.
description:
    According to the Wikipedia, a nonce is an arbitrary number used
    only once in a cryptographic communication.  This package
    contain helper functions for generating nonces.
    .
    There are many kinds of nonces used in different situations.
    It'\''s not guaranteed that by using the nonces from this package
    you won'\''t have any security issues.  Please make sure that the
    nonces generated via this package are usable on your design.
category: Cryptography
abi: 285c9c83a607653c1f132b067d3cafac
exposed: True
exposed-modules:
    Crypto.Nonce
import-dirs: /usr/lib/ghc-8.6.5/site-local/nonce-1.0.7
library-dirs: /usr/lib/ghc-8.6.5/site-local/nonce-1.0.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/nonce-1.0.7
hs-libraries: HSnonce-1.0.7-AfBGIvGcu2v3eRB2elWNvo
depends:
    base-4.12.0.0 base64-bytestring-1.0.0.2-Bm9gqw70QXoBbkNHszCarm
    bytestring-0.10.8.2 entropy-0.4.1.4-23NMAjgKyCo3F1ZCvvDJOh
    text-1.2.3.1 transformers-0.5.6.2
    unliftio-0.2.10-CRYQQSqya3N2TFXxVpglUK
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
haddock-interfaces: /usr/share/doc/haskell-nonce/html/nonce.haddock
haddock-html: /usr/share/doc/haskell-nonce/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
